@@ -12,7 +12,7 @@
  *  You may distribute this under the terms of either the GNU General Public
  *  License or the Artistic License, as specified in the Perl README file.
  *
- *  $Id: dbdimp.h 12860 2009-06-19 01:52:29Z capttofu $
+ *  $Id$
  */
 
 /*
@@ -49,6 +49,9 @@
 #define mysql_warning_count(svsock) 0
 #endif
 
+#define true 1
+#define false 0
+
 /*
  *  The following are return codes passed in $h->err in case of
  *  errors by DBD::mysql.
